@@ -16,4 +16,5 @@
     along with this program.  If not, see <http://www.gnu.org/licenses/>.
 """
 
-__version__ = '0.6.2'
+__version__ = '0.7'
+__timeout__ = 5
